@@ -2,9 +2,9 @@ def are_structfields_equal(sf1, sf2, ignore_nullability=False):
     if ignore_nullability:
         if sf1 is None and sf2 is not None:
             return False
-        if sf1 is not None and sf2 is None:
+        elif sf1 is not None and sf2 is None:
             return False
-        if sf1.name != sf2.name or sf1.dataType != sf2.dataType:
+        elif sf1.name != sf2.name or sf1.dataType != sf2.dataType:
             return False
         else:
             return True
